Court of Appeals Opinions | Nebraska Judicial Branch

Skip to main content
We have a new email notification provider. If you haven't already, please subscribe to alerts again.
Oral Arguments are happening now. View them live »
Official Nebraska Government Website

## You are here

# Court of Appeals Opinions

Tuesday, June 18, 2013
A-12-233, A-12-234 |  | In re Interest of Ray'Cine L.
A-12-779 |  | Schlichtman v. Jacob
A-12-994 |  | In re Interest of Marieanna N.
A-12-196 | 20 Neb. App. 850 | Rudd v. Debora
A-12-564 | 20 Neb. App. 861 | Geiss v. Geiss

Nebraska Judicial Branch